@@ -1,8 +1,5 @@
-"""
-Contains back-ends for qutrunk.
-"""
+"""Contains back-ends for qutrunk."""
 from .backend import Backend
 from .local import BackendLocal
 from .qusprout import BackendQuSprout, ExecType
 from .ibm import BackendIBM
-
