@@ -1,7 +1,6 @@
 """Circuit Module."""
 import json
 import random
-import sys
 from typing import List, Optional, Union
 
 from qutrunk.backends import Backend, BackendLocal
@@ -17,7 +16,7 @@ class QCircuit:
         density: Creates a density matrix Qureg object representing a set of \
             qubits which can enter noisy and mixed states.
         name: The circuit name.
-        resource: Enable the resource statistics function.
+        resource: Whether enable the resource statistics function, default: False.
 
     Example: 
         .. code-block:: python
@@ -38,11 +37,11 @@ class QCircuit:
     prefix = "circuit"
 
     def __init__(
-            self,
-            backend=None,
-            density=False,
-            name: Optional[str] = None,
-            resource: Optional[bool] = False,
+        self,
+        backend=None,
+        density=False,
+        name: Optional[str] = None,
+        resource: Optional[bool] = False,
     ):
         self.qreg = None
         self.creg = None
@@ -88,17 +87,21 @@ class QCircuit:
         """Allocate qubit in quantum circuit.
 
         Args:
-            qubits: int: The umber of qubit allocated in circuit.\
+            qubits: int: The number of qubit allocated in circuit.\
                     list: The sum of list is the umber of qubit allocated in circuit,\
                     and each value item represents the size of corresponding subqureg.
 
         Returns:
+            # TODO: update description and demo
             qreg: The register of quantum.
         """
-        if type(qubits) != int and type(qubits) != list:
-            raise TypeError("qubits parameter should be type of int or list")
+        if not isinstance(qubits, (int, list)):
+            raise TypeError("qubits parameter should be type of int or list.")
+
+        size = qubits if isinstance(qubits, int) else sum(qubits)
+        if size <= 0:
+            raise TypeError("Number of qubits should be larger than 0.")
 
-        size = qubits if type(qubits) == int else sum(qubits)
         self.qreg = Qureg(circuit=self, size=size)
         self.creg = CReg(circuit=self, size=size)
 
@@ -109,12 +112,11 @@ class QCircuit:
             self.qubit_indices[QuBit(self.qreg, index)] = index
             self.cbit_indices[CBit(self.creg, index)] = index
 
-        if type(qubits) == int:
+        if isinstance(qubits, int):
             return self.qreg
-        elif type(qubits) == list:
+        elif isinstance(qubits, list):
             return self.qreg.split(qubits)
 
-
     def set_cmds(self, cmds):
         """Set cmds to circuit.
 
@@ -267,6 +269,7 @@ class QCircuit:
         self.backend.send_circuit(self)
         return self.backend.get_prob_outcome(qubit, outcome)
 
+    # TODO:Get the maximum possible value of a qubit.
     def get_prob_all_outcome(self, qubits):
         """Get outcomeProbs with the probabilities of every outcome of the sub-register contained in qureg.
 
@@ -331,38 +334,31 @@ class QCircuit:
         return inverse_circuit, inverse_circuit.qreg
 
     @staticmethod
-    def from_qasm_file(file):
-        """Take in a QASM file and generate a QCircuit object.
+    def load(file, format=None):
+        """Deserialize file object containing a OpenQASM or qusl document to a Python object.
 
         Args:
-            file (str): Path to the file for a QASM program.
+            file (str): Path to the file for a qusl or OpenQASM program.
+            format(str): The format of file content.
 
         Return:
-            QCircuit: The QCircuit object for the input QASM.
+            QCircuit: The QCircuit object for the input qusl or OpenQASM.
+
         """
-        # pylint: disable=C0415，E0611，E1102
-        from qutrunk.qasm import Qasm
-        from qutrunk.converters import dag_to_circuit
-        from qutrunk.converters import ast_to_dag
+        if format is None or format == "qusl":
+            from qutrunk.tools.qusl_parse import qusl_to_circuit
 
-        qasm = Qasm(file)
-        ast = qasm.parse()
-        dag = ast_to_dag(ast)
-        return dag_to_circuit(dag)
+            return qusl_to_circuit(file)
 
-    @staticmethod
-    def from_qusl_file(file):
-        """Pase QuSL file and generate quantum circuit.
+        if format == "openqasm":
+            from qutrunk.qasm import Qasm
+            from qutrunk.converters import dag_to_circuit
+            from qutrunk.converters import ast_to_dag
 
-        Args:
-            file: The input QuSL file(json format).
-
-        Returns:
-            QCircuit object.
-        """
-        from qutrunk.tools.qusl_parse import qusl_to_circuit
-
-        return qusl_to_circuit(file)
+            qasm = Qasm(file)
+            ast = qasm.parse()
+            dag = ast_to_dag(ast)
+            return dag_to_circuit(dag)
 
     def expval(self, obs_data):
         """Computes the expected value of a product of Pauli operators.
@@ -394,80 +390,102 @@ class QCircuit:
         pauli_type_list, coeffi_list = pauli_coeffi.obs_data()
         if (qubitnum != 0) and (len(coeffi_list) * qubitnum) != len(pauli_type_list):
             raise AttributeError(
-                "parameter error：the number of parameters is not correct."
+                "Parameter error: The number of parameters is not correct."
             )
         return self.backend.get_expec_pauli_sum(pauli_type_list, coeffi_list)
 
-    def print(self, file=None, unroll=True):
-        """Print quantum circuit in qutrunk form.
-        
-        Args:
-            unroll: True: Dump the detailed instructions, especially, \
-                if the instruction contains an operator, the operator will be expanded.
-                False: Dump the brief instructions, the operator will not be expanded.
-            file: Dump the qutrunk instruction to file(json format). 
-        """
-        try:
-            f = open(file, "w", encoding="utf-8") if file else sys.stdout
-            if f is sys.stdout:
-                """Print quantum circuit in qutrunk form."""
-                print(f"qreg q[{str(len(self.qreg))}]")
-                print(f"creg c[{str(len(self.qreg))}]")
-                if unroll:
-                    for c in self:
-                        print(c.qusl())
-                else:
-                    for stm in self.statements:
-                        print(stm)
+    def _dump_qusl(self, file, unroll=True):
+        with open(file, "w", encoding="utf-8") as f:
+            qusl_data = {}
+            qusl_data["target"] = "QuSL"
+            qusl_data["version"] = "1.0"
+
+            meta = {"circuit_name": self.name, "qubits": str(len(self.qreg))}
+            qusl_data["meta"] = meta
+
+            inst = []
+            if unroll:
+                for c in self:
+                    inst.append(c.qusl() + "\n")
             else:
-                qusl_data = {}
-                qusl_data["target"] = "QuSL"
-                qusl_data["version"] = "1.0"
+                for stm in self.statements:
+                    inst.append(stm + "\n")
 
-                meta = {}
-                meta["circuit_name"] = self.name
-                meta["qubits"] = str(len(self.qreg))
-                qusl_data["meta"] = meta
-
-                inst = []
-                if unroll:
-                    for c in self:
-                        inst.append(c.qusl() + "\n")
-                else:
-                    for stm in self.statements:
-                        inst.append(stm + "\n")
-                qusl_data["code"] = inst
-                qusl_json = json.dumps(qusl_data)
-                f.write(qusl_json)
-        finally:
-            if f is not sys.stdout:
-                f.close()
-
-    def print_qasm(self, file=None):
-        """Convert circuit and dump to file/stdout.
-
-        Convert circuit to QASM 2.0, and dump to file/stdout.
-        TODO: custom gate implemented by qutrunk can't be parsed by third party.
-        Refer to qulib1.inc and mapping.qutrunk_standard_gate.
-
-        Args:
-            file: Dump the qasm to file.
-        """
-        try:
-            f = open(file, "w") if file else sys.stdout
+            qusl_data["code"] = inst
+            f.write(json.dumps(qusl_data))
 
+    def _dump_openqasm(self, file):
+        with open(file, "w", encoding="utf-8") as f:
             f.write("OPENQASM 2.0;\n")
             f.write('include "qulib1.inc";\n')
             f.write(f"qreg q[{str(len(self.qreg))}];\n")
             f.write(f"creg c[{str(len(self.qreg))}];\n")
             for c in self:
                 f.write(c.qasm() + ";\n")
-        finally:
-            # don't close sys.stdout
-            if f is not sys.stdout:
-                f.close()
 
-    def depth(self, counted_gate: Optional[callable] = lambda x: not isinstance(x, BarrierGate)) -> int:
+    def dump(self, file=None, format=None, unroll=True):
+        """Serialize Quantum circuit as a JSON formatted stream to file.
+
+        Args:
+            unroll: True: Dump the detailed instructions, especially, \
+                if the instruction contains an operator, the operator will be expanded.
+                False: Dump the brief instructions, the operator will not be expanded.
+            file: Dump the qutrunk instruction to file(json format).
+        """
+        if file is None:
+            raise Exception("file argument need to be supplied.")
+
+        if format is None or format == "qusl":
+            self._dump_qusl(file, unroll)
+
+        if format == "openqasm":
+            self._dump_openqasm(file)
+
+    def _print_qusl(self, unroll):
+        """Print quantum circuit in qutrunk form.
+
+        Args:
+            unroll: True: Dump the detailed instructions, especially, \
+                if the instruction contains an operator, the operator will be expanded.
+                False: Dump the brief instructions, the operator will not be expanded.
+        """
+        print(f"qreg q[{str(len(self.qreg))}]")
+        print(f"creg c[{str(len(self.qreg))}]")
+        if unroll:
+            for c in self:
+                print(c.qusl())
+        else:
+            for stm in self.statements:
+                print(stm)
+
+    def _print_qasm(self):
+        """Print quantum circuit in OpenQASM form."""
+        print("OPENQASM 2.0;")
+        print('include "qulib1.inc";')
+        print(f"qreg q[{str(len(self.qreg))}];")
+        print(f"creg c[{str(len(self.qreg))}];")
+        for c in self:
+            print(c.qasm() + ";")
+
+    def print(self, format=None, unroll=True):
+        """Print quantum circuit.
+
+        Args:
+            format(str): The format of needed to print, Default to qusl. options are "qusl" or "openqasm".
+            unroll: True: Dump the detailed instructions, especially, \
+                if the instruction contains an operator, the operator will be expanded.
+                False: Dump the brief instructions, the operator will not be expanded.
+        """
+        if format is None or format == "qusl":
+            self._print_qusl(unroll)
+
+        if format == "openqasm":
+            self._print_qasm()
+
+    def depth(
+        self,
+        counted_gate: Optional[callable] = lambda x: not isinstance(x, BarrierGate),
+    ) -> int:
         """Return circuit depth (i.e., max length of critical path).
 
         Args:
@@ -538,14 +556,14 @@ class QCircuitIter:
 
     def __init__(self, cmds):
         self.idx = 0
-        self.cmds = cmds
+        self.__cmds  = cmds
 
     def __iter__(self):
         return self
 
     def __next__(self):
         try:
-            cmd = self.cmds[self.idx]
+            cmd = self.__cmds[self.idx]
         except IndexError:
             raise StopIteration
 
@@ -583,7 +601,7 @@ class Result:
     """
 
     def __init__(
-            self, num_qubits, res, backend, arguments, task_id=None, status="success"
+        self, num_qubits, res, backend, arguments, task_id=None, status="success"
     ):
         self.states = []
         self.values = []
