@@ -1,8 +1,47 @@
 from qutrunk.circuit.gates import (
-    MCX, CYGate, MCZ, SwapGate, HGate, SGate, SdgGate, SqrtXGate,
-    TGate, TdgGate, P, U1, U2, U3, U, CU, CU1, CU3,
-    XGate, YGate, ZGate, Rx, Ry, Rz, Rxx, Rzz, CP, CRx, CRy, CRz, R, Ryy, SqrtSwapGate, iSwap, CR, X1Gate,
-    Y1Gate, Z1Gate, IGate, SqrtXdgGate, CHGate, CSqrtXGate, CSwapGate
+    MCX,
+    CYGate,
+    MCZ,
+    SwapGate,
+    HGate,
+    SGate,
+    SdgGate,
+    SqrtXGate,
+    TGate,
+    TdgGate,
+    P,
+    U1,
+    U2,
+    U3,
+    U,
+    CU,
+    CU1,
+    CU3,
+    XGate,
+    YGate,
+    ZGate,
+    Rx,
+    Ry,
+    Rz,
+    Rxx,
+    Rzz,
+    CP,
+    CRx,
+    CRy,
+    CRz,
+    R,
+    Ryy,
+    SqrtSwapGate,
+    iSwap,
+    CR,
+    X1Gate,
+    Y1Gate,
+    Z1Gate,
+    IGate,
+    SqrtXdgGate,
+    CHGate,
+    CSqrtXGate,
+    CSwapGate,
 )
 
 # qasm的量子门映射到qutrunk的量子门
@@ -45,7 +84,6 @@ qutrunk_standard_gate = {
     # "ccx": MCX(2), # qutrunk implement by MCX
     "cswap": CSwapGate,
     # "delay": Delay,
-
     # qutrunk only gate
     "r": R,
     "ryy": Ryy,
@@ -56,5 +94,5 @@ qutrunk_standard_gate = {
     "y1": Y1Gate,
     "z1": Z1Gate,
     "mcx": MCX,
-    "mcz": MCZ
+    "mcz": MCZ,
 }
