@@ -1,39 +1,43 @@
-"""
-Bell state example.
-"""
+"""Bell state example."""
 from qutrunk.circuit import QCircuit
 from qutrunk.circuit.gates import H, CNOT, Measure
 
 
 def run_bell_pair(backend=None):
-    # allocate
+    # Create quantum circuit
     qc = QCircuit(backend=backend)
 
+    # Allocate quantum qubits
     qr = qc.allocate(2)
 
-    # apply gate
+    # Apply quantum gates
     H * qr[0]
     CNOT * (qr[0], qr[1])
     Measure * qr[0]
     Measure * qr[1]
 
+    # Print quantum circuit
+    qc.print()
 
-
-    # print circuit
-    qc.print(file="bell_pair.qusl")
-
-    # run circuit
+    # Run quantum circuit with 100 times
     res = qc.run(shots=100)
 
-    # print result
+    # Print result like:
+    #[1, 1]
+    #[{"00": 50}, {"11": 50}]
     print(res.get_measure())
     print(res.get_counts())
-    print(res.excute_info())
 
+    # Print quantum circuit exection information
+    print(res.excute_info())
 
     return qc
 
 
 if __name__ == "__main__":
+    # Run locally
     circuit = run_bell_pair()
+
+    # Draw quantum circuit
     circuit.draw()
+
