@@ -1,6 +1,7 @@
+"""Bernstein-Vazirani example."""
+
 from qutrunk.circuit import QCircuit
 from qutrunk.circuit.gates import CNOT, X
-from qutrunk.backends import BackendQuSprout
 
 
 def run_bernstein_vazirani(backend=None):
