@@ -1,7 +1,8 @@
 import json
 from collections import defaultdict
 from qutrunk.circuit import QCircuit
-from qutrunk.circuit.gates import H,CNOT,Measure
+from qutrunk.circuit.gates import H, CNOT, Measure
+
 qc = QCircuit()
 qr = qc.allocate(2)
 H | qr[0]
@@ -14,8 +15,8 @@ Tree = lambda: defaultdict(Tree)
 tree = Tree()
 for index, item in enumerate(outcome):
     i = str(bin(index))[2:]
-    tree['probs'][i]['probability'] = item
-    tree['probs'][i]['angle'] = 0
+    tree["probs"][i]["probability"] = item
+    tree["probs"][i]["angle"] = 0
 print(json.dumps(tree))
-with open(file=r'result.json', mode='w', encoding='utf-8') as f:
+with open(file=r"result.json", mode="w", encoding="utf-8") as f:
     file = json.dump(json.dumps(tree), f)
